#ifndef LEGACYAPP_H
#define LEGACYAPP_H

#include <QObject>
#include <QSettings>
#include <QApplication>

#include <LotroDat/LotroDat.h>

class Lotro : public QObject
{
    Q_OBJECT

public:
    explicit Lotro(QSettings& app_settings_, QObject *parent = nullptr);

    bool initialised();

    int currentLocale();

    bool patched();

public slots:
    void initialiseDatFile(QString file_name);

    void changeLocale();

    void getLocaleFileContents(long long file_id, int locale);

    void importFilesFromDatabase(QString database_path);

    void importFile(long long file_id, QString file_path);

    void importTextFragment(long long file_id, long long fragment_id, QString fragment_contents, QString arguments);

    void getTextFragment(long long file_id, long long fragment_id);

    void createCoreStatusFile(QString output_filename);

    void extractSingleFile(QString output_filename, long long file_id);

    void extractSingleFileToDatabase(QString database_path, long long file_id);

    void extractGrouppedFiles(QString output_foldername, LOTRO_DAT::FILE_TYPE type);

    void extractGrouppedFilesToDatabase(QString database_path, LOTRO_DAT::FILE_TYPE type);

    void getUnactiveCategories();

    void startGame();

private:
    bool tryToBlockFile();

signals:
    // general signals. First argument is process_name, second - processed values
    void processStarted(QString, QList<QVariant>);
    void processFinished(QString, QList<QVariant>);
    void processUpdated(QString, QList<QVariant>);
    void caughtError(QString, QList<QVariant>);

    void TextFragmentReceived(QString, QString);
    void UnactiveCategoriesReceived(QStringList);
    void LocaleFileContentsReceived(int, LOTRO_DAT::SubfileData); // extention, contents

private:
    LOTRO_DAT::DatFile file;
    bool busy;
    QSettings& app_settings;
};

#endif // LEGACYAPP_H
